tailscale

package
v0.2.67 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 13, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client represents a Tailscale client for managing VPN connections and Funnel exposure

func NewClient

func NewClient() *Client

NewClient creates a new Tailscale client

func (*Client) Connect

func (c *Client) Connect(authKey string) error

Connect connects to Tailscale using the provided auth key

func (*Client) CreateIngressWithFunnel added in v0.2.10

func (c *Client) CreateIngressWithFunnel(serviceName, hostname string, port int) error

CreateIngressWithFunnel creates a Kubernetes ingress with Tailscale Funnel enabled

func (*Client) DisableFunnel added in v0.2.10

func (c *Client) DisableFunnel() error

DisableFunnel disables Tailscale Funnel

func (*Client) Disconnect

func (c *Client) Disconnect() error

Disconnect disconnects from Tailscale

func (*Client) EnableFunnel added in v0.2.10

func (c *Client) EnableFunnel(port int) error

EnableFunnel enables Tailscale Funnel for port 80 exposure

func (*Client) GetFunnelStatus added in v0.2.10

func (c *Client) GetFunnelStatus() (string, error)

GetFunnelStatus returns the current Funnel status

func (*Client) GetFunnelURL added in v0.2.10

func (c *Client) GetFunnelURL() (string, error)

GetFunnelURL returns the public URL for the Funnel service

func (*Client) GetIP

func (c *Client) GetIP() (string, error)

GetIP returns the Tailscale IP address

func (*Client) GetStatus

func (c *Client) GetStatus() (string, error)

GetStatus returns the current Tailscale status

func (*Client) InstallTailscale added in v0.2.10

func (c *Client) InstallTailscale() error

InstallTailscale installs Tailscale on the system

func (*Client) IsConnected

func (c *Client) IsConnected() (bool, error)

IsConnected checks if Tailscale is connected and active

func (*Client) IsInstalled

func (c *Client) IsInstalled() bool

IsInstalled checks if Tailscale is installed on the system

func (*Client) ListPeers

func (c *Client) ListPeers() ([]string, error)

ListPeers returns a list of connected peers

func (*Client) Ping

func (c *Client) Ping(peer string) error

Ping pings a peer in the Tailscale network

func (*Client) SetupKubernetesOperator added in v0.2.10

func (c *Client) SetupKubernetesOperator() error

SetupKubernetesOperator installs and configures the Tailscale Kubernetes operator

Jump to