Documentation
¶
Index ¶
- type Client
- func (c *Client) Connect(authKey string) error
- func (c *Client) CreateIngressWithFunnel(serviceName, hostname string, port int) error
- func (c *Client) DisableFunnel() error
- func (c *Client) Disconnect() error
- func (c *Client) EnableFunnel(port int) error
- func (c *Client) GetFunnelStatus() (string, error)
- func (c *Client) GetFunnelURL() (string, error)
- func (c *Client) GetIP() (string, error)
- func (c *Client) GetStatus() (string, error)
- func (c *Client) InstallTailscale() error
- func (c *Client) IsConnected() (bool, error)
- func (c *Client) IsInstalled() bool
- func (c *Client) ListPeers() ([]string, error)
- func (c *Client) Ping(peer string) error
- func (c *Client) SetupKubernetesOperator() error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client represents a Tailscale client for managing VPN connections and Funnel exposure
func (*Client) CreateIngressWithFunnel ¶ added in v0.2.10
CreateIngressWithFunnel creates a Kubernetes ingress with Tailscale Funnel enabled
func (*Client) DisableFunnel ¶ added in v0.2.10
DisableFunnel disables Tailscale Funnel
func (*Client) Disconnect ¶
Disconnect disconnects from Tailscale
func (*Client) EnableFunnel ¶ added in v0.2.10
EnableFunnel enables Tailscale Funnel for port 80 exposure
func (*Client) GetFunnelStatus ¶ added in v0.2.10
GetFunnelStatus returns the current Funnel status
func (*Client) GetFunnelURL ¶ added in v0.2.10
GetFunnelURL returns the public URL for the Funnel service
func (*Client) InstallTailscale ¶ added in v0.2.10
InstallTailscale installs Tailscale on the system
func (*Client) IsConnected ¶
IsConnected checks if Tailscale is connected and active
func (*Client) IsInstalled ¶
IsInstalled checks if Tailscale is installed on the system
func (*Client) SetupKubernetesOperator ¶ added in v0.2.10
SetupKubernetesOperator installs and configures the Tailscale Kubernetes operator