utils

package
v0.0.24 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 29, 2024 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

utils/utils.go

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsValidURL

func IsValidURL(testURL string) bool

IsValidURL checks if the provided string is a valid URL.

func RunCommand

func RunCommand(name string, args ...string) (string, error)

RunCommand executes a shell command and returns its output or an error.

func ValidateOrPrompt

func ValidateOrPrompt()

Types

This section is empty.

Jump to