Documentation
¶
Overview ¶
utils/utils.go
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsValidURL ¶
IsValidURL checks if the provided string is a valid URL.
func RunCommand ¶
RunCommand executes a shell command and returns its output or an error.
func ValidateOrPrompt ¶
func ValidateOrPrompt()
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.